@@ -160,16 +160,16 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         # database collation.
         'exact': '= %s',
         'iexact': "= UPPER(%s)",
-        'contains': "LIKE %s ESCAPE '\\'",
-        'icontains': "LIKE UPPER(%s) ESCAPE '\\'",
+        'contains': "LIKE %s ",
+        'icontains': "LIKE UPPER(%s) ",
         'gt': '> %s',
         'gte': '>= %s',
         'lt': '< %s',
         'lte': '<= %s',
-        'startswith': "LIKE %s ESCAPE '\\'",
-        'endswith': "LIKE %s ESCAPE '\\'",
-        'istartswith': "LIKE UPPER(%s) ESCAPE '\\'",
-        'iendswith': "LIKE UPPER(%s) ESCAPE '\\'",
+        'startswith': "LIKE %s ",
+        'endswith': "LIKE %s ",
+        'istartswith': "LIKE UPPER(%s) ",
+        'iendswith': "LIKE UPPER(%s) ",
 
         # TODO: remove, keep native T-SQL LIKE wildcards support
         # or use a "compatibility layer" and replace '*' with '%'
