@@ -302,9 +302,8 @@ class DatabaseOperations(BaseDatabaseOperations):
 
     def prep_for_like_query(self, x):
         """Prepares a value for use in a LIKE query."""
-        # http://msdn2.microsoft.com/en-us/library/ms179859.aspx
-        return smart_text(x).replace('\\', '\\\\').replace('[', '[[]').replace('%', '[%]').replace('_', '[_]')
-
+        return x
+        
     def prep_for_iexact_query(self, x):
         """
         Same as prep_for_like_query(), but called for "iexact" matches, which
